# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class ExternalPropertyFileReference(object):
    """Contains information that enables a SARIF consumer to locate the external property file that contains the value of an externalized property associated with the run."""

    guid = attr.ib(default=None, metadata={"schema_property_name": "guid"})
    item_count = attr.ib(default=-1, metadata={"schema_property_name": "itemCount"})
    location = attr.ib(default=None, metadata={"schema_property_name": "location"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
